<?php
namespace Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Error;

class Mym00105LocalPesqController extends \Teknisa\GER\Controllers\TeknisaCrud {
    protected $dataSourceName = 'local_pesq_produto';
    protected $dataSourceNameToSave = 'produtolocalpesq';
    protected $entityManager;
    protected $fileServerFilesUrl;
    
    public function __construct($crudService, $parameterBag, $Mym00105LocalPesqService, $fileServerFilesUrl, $entityManager){
        parent::__construct($crudService, $parameterBag);
        $this->fileServerFilesUrl = $fileServerFilesUrl;
        $this->entityManager = $entityManager;
        $this->Mym00105LocalPesqService = $Mym00105LocalPesqService;
    }
    
    public function save(DTO\Request $request, DTO\Response $response){
		try {
			$dataSourceName = $this->dataSourceNameToSave ? $this->dataSourceNameToSave : $this->dataSourceName;
			$rows = $this->crudService->getRowsToSave($request, $dataSourceName);
			$rowsToSave = [];
			foreach($rows as $row) {
			    $imageCol = array_key_exists("URL_FOTO", $row) ? $row['URL_FOTO'] : false;
			    if ($imageCol && gettype($imageCol) !== "string") {
			        $imageColValue = null;
    			    if (gettype($imageCol) === "array") {
    			        if (sizeof($imageCol) > 0) {
    			            $fileObject = $imageCol[0];
    			            if (gettype($fileObject) === "array" && array_key_exists("type", $fileObject) && array_key_exists("path", $fileObject)) {
        			            $fileType = $fileObject['type'];
        			            if (substr($fileType, 0, 5) === "image") {
        			                $imageColValue = $fileObject['path'];
        			            }
    			            }
    			        }
    			    }
    			    $row['URL_FOTO'] = $imageColValue;
			    } else if ($imageCol && gettype($imageCol) === "string") {
			       $row['URL_FOTO'] = str_replace($this->fileServerFilesUrl, "", $row['URL_FOTO']);
			    }
			    array_push($rowsToSave, $row);
			}
			$this->crudService->save($dataSourceName, $rowsToSave);
            $response->addDataSet(new DataSet("columnsToReturn", $this->crudService->getColumnsToReturn()));
		} catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
		}
    }

	public function find(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $filterCriteria = $request->getFilterCriteria();
            $filterCriteria->setDataSourceName($this->dataSourceName);
            $filterCriteria = $this->crudService->getFilterCriteriaWithNrOrg($filterCriteria);
            $newFilterCriteria = $this->crudService->getPopulatedFilterCriteria($filterCriteria, $this->parameterBagColumns);
            $this->crudService->find($response, $newFilterCriteria);
	        
	        $responseDataSourceName = substr($request->getRoutePath(), 1);
	        $responseRows = [];
	        foreach ($response->getDataSets()[0]->getRows() as $row) {
	            $imageCol = array_key_exists("URL_FOTO", $row) ? $row['URL_FOTO'] : false;
			    if ($imageCol && gettype($imageCol) === "string") {
    			    $row['URL_FOTO'] = $this->fileServerFilesUrl.$row['URL_FOTO'];
			    }
	            array_push($responseRows, $row);
	        }
	        
	        $responseDataSet = new DataSet($responseDataSourceName, $responseRows);
	        $response->setDataSets([$responseDataSet]);
	        
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function exportProdutoLocalPesq(DTO\Request $request, DTO\Response $response) {
	    try{
	    	$row = $request->getRow();
	    	
	    	$nrlocalpesqOri = $row['NRLOCALPESQORIG'];
	    	$filiais = implode('_',$row['NMFILIAL']);
	    	$produtos = implode('_', array_column($row['produtos'], 'NRPRODUTOLOCALPESQ'));

	    	$nrlocalpesqDest = empty($row['NMLOCALPESQ']) ? $this->Mym00105LocalPesqService->retornaLocais($filiais, $nrlocalpesqOri) : $row['NMLOCALPESQ'];
			$tipoExport = $row['TPExport'];

			$this->Mym00105LocalPesqService->exportaProdutos($tipoExport, $nrlocalpesqOri,$nrlocalpesqDest, $produtos);

	    } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }	    	
}